summaryrefslogtreecommitdiff
path: root/src/jit/inline.cpp
diff options
context:
space:
mode:
authorPat Gavlin <pagavlin@microsoft.com>2016-05-12 14:32:13 -0700
committerPat Gavlin <pagavlin@microsoft.com>2016-05-12 16:20:20 -0700
commit8172ccaa93df60a46712f3453a4871ce0026f3ea (patch)
tree7b092e72b2efb2a947ea79a4702e4f52766978f1 /src/jit/inline.cpp
parentc1181048d92afa49043cdd4ef50962eb2a949007 (diff)
downloadcoreclr-8172ccaa93df60a46712f3453a4871ce0026f3ea.tar.gz
coreclr-8172ccaa93df60a46712f3453a4871ce0026f3ea.tar.bz2
coreclr-8172ccaa93df60a46712f3453a4871ce0026f3ea.zip
Use a JIT-specific stdout `FILE*`.
Historically, the JIT has had issues with logging inside of processes that change the output mode of stdout (e.g. crossgen). This change replaces the previous solution (which relied on #ifdefs) by dup'ing the stdout file and wrapping it in a new `FILE*` set to a known output mode.
Diffstat (limited to 'src/jit/inline.cpp')
-rw-r--r--src/jit/inline.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/jit/inline.cpp b/src/jit/inline.cpp
index 1f728dd59f..f39c553310 100644
--- a/src/jit/inline.cpp
+++ b/src/jit/inline.cpp
@@ -345,7 +345,7 @@ InlineContext::InlineContext(InlineStrategy* strategy)
#if defined(DEBUG) || defined(INLINE_DATA)
//------------------------------------------------------------------------
// Dump: Dump an InlineContext entry and all descendants to stdout
//
// Arguments:
// indent - indentation level for this node
@@ -451,7 +451,7 @@ void InlineContext::DumpData(unsigned indent)
{
const char* inlineReason = InlGetObservationString(m_Observation);
printf("%*s%u,\"%s\",\"%s\"", indent, "", m_Ordinal, inlineReason, calleeName);
- m_Policy->DumpData(stdout);
+ m_Policy->DumpData(jitstdout);
printf("\n");
}
@@ -345,7 +345,7 @@ InlineContext::InlineContext(InlineStrategy* strategy)
#if defined(DEBUG) || defined(INLINE_DATA)
//------------------------------------------------------------------------
-// Dump: Dump an InlineContext entry and all descendants to stdout
+// Dump: Dump an InlineContext entry and all descendants to jitstdout
//
// Arguments: